"""Data loading and preprocessing."""


class DataLoader:
    """Custom data loader."""
    
    def __init__(self, data_path):
        self.data_path = data_path
    
    def load(self):
        """Load data from disk."""
        pass
    
    def preprocess(self, data):
        """Preprocess data."""
        pass
